@@ -269,7 +269,7 @@ class GenericMaster(GenericJob):
             for child_id in original.child_ids:
                 child = original.project.load(child_id)
                 new_child = child.copy_to(
-                    project=file_project.open(self.job_name + "_hdf5"),
+                    project=self.project.open(self.job_name + "_hdf5"),
                     new_database_entry=new_database_entry,
                 )
                 if new_database_entry and child.parent_id:
